@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 __END__
@@ -15,7 +15,7 @@ OIDC::Lite - OpenID Connect Library
 
 =head1 DESCRIPTION
 
-OpenID Connect Library
+OpenID Connect Server/Client Library
 
 =head1 AUTHOR
 
