@@ -1,58 +1,66 @@
 package OIDC::Lite::Server::DataHandler;
-
 use strict;
 use warnings;
-
-use Params::Validate;
-use OAuth::Lite2::Server::Error;
 use parent 'OAuth::Lite2::Server::DataHandler';
 
 sub validate_client_for_authorization {
     my ($self, $client_id, $response_type) = @_;
     die "abstract method";
-    return 1;
 }
 
 sub validate_redirect_uri {
     my ($self, $client_id, $redirect_uri) = @_;
     die "abstract method";
-    return 1;
 }
 
 sub validate_scope {
     my ($self, $client_id, $scope) = @_;
     die "abstract method";
-    return 1;
 }
 
 sub validate_display {
     my ($self, $display) = @_;
     die "abstract method";
-    return 1;
 }
 
 sub validate_prompt {
     my ($self, $prompt) = @_;
     die "abstract method";
-    return 1;
+}
+
+sub validate_max_age {
+    my ($self, $param) = @_;
+    die "abstract method";
+}
+
+sub validate_ui_locales {
+    my ($self, $ui_locales) = @_;
+    die "abstract method";
+}
+
+sub validate_claims_locales {
+    my ($self, $claims_locales) = @_;
+    die "abstract method";
+}
+
+sub validate_id_token_hint {
+    my ($self, $param) = @_;
+    die "abstract method";
+}
+
+sub validate_login_hint {
+    my ($self, $param) = @_;
+    die "abstract method";
 }
 
 sub validate_request {
     my ($self, $param) = @_;
     die "abstract method";
-    return 1;
 }
 
 sub validate_request_uri {
     my ($self, $param) = @_;
     die "abstract method";
-    return 1;
-}
-
-sub validate_id_token {
-    my ($self, $id_token) = @_;
-    die "abstract method";
-    return 1;
 }
 
 sub get_user_id_for_authorization {
@@ -68,31 +76,6 @@ sub create_id_token {
 
 sub create_or_update_auth_info {
     my ($self, %args) = @_;
-    Params::Validate::validate(@_, {
-        client_id   => 1,
-        user_id     => 1,
-        scope       => { optional => 1 },
-        id_token    => { optional => 1 },
-    });
-    die "abstract method";
-}
-
-# methods for Dynamic Client Registration
-# spec supported http://openid.net/specs/openid-connect-registration-1_0-14.html
-## register and return client metadata
-sub client_associate {
-    my ($self, $param, $access_token) = @_;
-    die "abstract method";
-}
-
-## update and return client metadata
-sub client_update {
-    my ($self, $param, $access_token) = @_;
-    die "abstract method";
-}
-
-sub rotate_secret {
-    my ($self, $access_token) = @_;
     die "abstract method";
 }
 
@@ -100,14 +83,27 @@ sub rotate_secret {
 
 OIDC::Lite::Server::DataHandler - Base class that specifies interface for data handler for your service.
 
-=head1 SYNOPSIS
-
 =head1 DESCRIPTION
 
 This specifies interface to handle data stored on your application.
 You have to inherit this, and implements subroutines according to the interface contract.
 This is proxy or adapter that connects OIDC::Lite library to your service.
 
+=head1 SYNOPSIS
+
+    package YourDataHandler;
+    
+    use strict;
+    use warnings;
+
+    use parent 'OIDC::Lite::Server::DataHandler';
+
+    sub validate_scope {
+        my ($self, $client_id, $scope) = @_;
+        # your logic
+        return 1;
+    }
+
 =head1 METHODS
 
 =head2 init
@@ -145,6 +141,36 @@ If it's OK, return 1. Return 0 if not.
 Validation of prompt param.
 If it's OK, return 1. Return 0 if not.
 
+=head2 validate_max_age( $aram )
+
+Validation of max_age param.
+If it's OK, return 1. Return 0 if not.
+
+=head2 validate_ui_locales_( $ui_locales )
+
+Validation of ui_locales param.
+If it's OK, return 1. Return 0 if not.
+
+=head2 validate_claims_locales_( $claims_locales )
+
+Validation of claims_locales param.
+If it's OK, return 1. Return 0 if not.
+
+=head2 validate_id_token_hint( $param )
+
+Validation of id_token_hint param.
+If it's OK, return 1. Return 0 if not.
+
+=head2 validate_login_hint( $param )
+
+Validation of login_hint param.
+If it's OK, return 1. Return 0 if not.
+
+=head2 validate_acr_values( $param 
+
+Validation of acr_values param.
+If it's OK, return 1. Return 0 if not.
+
 =head2 validate_request( $param )
 
 Validation of request param.
@@ -167,18 +193,6 @@ Return OIDC::Lite::Model::IDToken object.
 
 Return OIDC::Lite::Model::AuthInfo object.
 
-=head2 client_associate($param, $access_token) 
-
-Return OIDC::Lite::Model::ClientInfo object.
-
-=head2 client_update($param, $access_token) 
-
-Return OIDC::Lite::Model::ClientInfo object.
-
-=head2 rotate_secret($access_token)
-
-Return OIDC::Lite::Model::ClientInfo object.
-
 =head1 AUTHOR
 
 Ryo Ito, E<lt>ritou.06@gmail.comE<gt>
